==> orchestra-pvm-4.2.1-sources.jar: org/ow2/orchestra/pvm/internal/cmd/SetVariablesCmd.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.pvm.internal.cmd;

import org.ow2.orchestra.pvm.Execution;
import org.ow2.orchestra.pvm.PvmException;
import org.ow2.orchestra.pvm.client.ClientExecution;
import org.ow2.orchestra.pvm.env.Environment;

/**
 * @author Tom Baeyens
 */
public class SetVariablesCmd extends VariablesCmd<Execution> {

  private static final long serialVersionUID = 1L;

  protected String executionId = null;

  public SetVariablesCmd(String executionId) {
    if (executionId == null) {
      throw new PvmException("executionId is null");
    }
    this.executionId = executionId;
  }

  public SetVariablesCmd(String executionId, String key, Object variable) {
    this(executionId);
    addVariable(key, variable);
  }

  public Execution execute(Environment environment) throws Exception {
    ClientExecution execution = getExecution(environment, executionId);
    execution.setVariables(variables);
    return execution;
  }

  public String getExecutionId() {
    return executionId;
  }
}

==> orchestra-pvm-4.4.1-sources.jar: org/ow2/orchestra/pvm/internal/cmd/SetVariablesCmd.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.ow2.orchestra.pvm.internal.cmd;

import org.ow2.orchestra.pvm.Execution;
import org.ow2.orchestra.pvm.PvmException;
import org.ow2.orchestra.pvm.client.ClientExecution;
import org.ow2.orchestra.pvm.env.Environment;

/**
 * @author Tom Baeyens
 */
public class SetVariablesCmd extends VariablesCmd<Execution> {

  private static final long serialVersionUID = 1L;

  protected String executionId = null;

  public SetVariablesCmd(final String executionId) {
    if (executionId == null) {
      throw new PvmException("executionId is null");
    }
    this.executionId = executionId;
  }

  public SetVariablesCmd(final String executionId, final String key, final Object variable) {
    this(executionId);
    this.addVariable(key, variable);
  }

  public Execution execute(final Environment environment) {
    final ClientExecution execution = this.getExecution(environment, this.executionId);
    execution.setVariables(this.variables);
    return execution;
  }

  public String getExecutionId() {
    return this.executionId;
  }
}
